aboutsummaryrefslogtreecommitdiff
path: root/lib/xixanta
diff options
context:
space:
mode:
authorMiquel Sabaté Solà <mssola@mssola.com>2026-04-30 13:17:52 +0200
committerMiquel Sabaté Solà <mssola@mssola.com>2026-04-30 13:17:52 +0200
commitaf7a9b22bd010d37685169889b4d3fba5b48b844 (patch)
treee83e3c2350620c70c65f0470487a67715924df65 /lib/xixanta
parentfdfc017b68a397fc2a1c02378a6c86ca7966954d (diff)
downloadtools.nes-af7a9b22bd010d37685169889b4d3fba5b48b844.tar.gz
tools.nes-af7a9b22bd010d37685169889b4d3fba5b48b844.zip
Rename "raw address" to "label"
This is much clearer to the programmer. Signed-off-by: Miquel Sabaté Solà <mssola@mssola.com>
Diffstat (limited to 'lib/xixanta')
-rw-r--r--lib/xixanta/src/object.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/xixanta/src/object.rs b/lib/xixanta/src/object.rs
index 8867af3..1887b77 100644
--- a/lib/xixanta/src/object.rs
+++ b/lib/xixanta/src/object.rs
@@ -126,7 +126,7 @@ pub enum ObjectType {
impl std::fmt::Display for ObjectType {
fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
match self {
- ObjectType::Address => write!(f, "raw address"),
+ ObjectType::Address => write!(f, "label"),
ObjectType::Proc => write!(f, "proc"),
ObjectType::Value => write!(f, "variable"),
ObjectType::Argument => write!(f, "macro argument"),
@@ -260,7 +260,7 @@ impl Context {
var.accessed += 1;
Ok(var.clone())
}
// If it's a .proc or a raw address, then we account for the
// number of times it was accessed, and we return the
// resolved value.
ObjectType::Address | ObjectType::Proc => {
@@ -260,7 +260,7 @@ impl Context {
Ok(var.clone())
}
- // If it's a .proc or a raw address, then we account for the
+ // If it's a .proc or a label, then we account for the
// number of times it was accessed, and we return the
// resolved value.